(()=>{"use strict";var a={d:(e,p)=>{for(var t in p)a.o(p,t)&&!a.o(e,t)&&Object.defineProperty(e,t,{enumerable:!0,get:p[t]})},o:(a,e)=>Object.prototype.hasOwnProperty.call(a,e),r:a=>{"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(a,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(a,"__esModule",{value:!0})}},e={};a.r(e),a.d(e,{UpgreekConfiguration:()=>c});const p=("undefined"!=typeof window?window:global).MathJax._.components.global,t=(p.GLOBAL,p.isObject,p.combineConfig,p.combineDefaults,p.combineWithMathJax),n=(p.MathJax,MathJax._.input.tex.HandlerTypes),o=n.ConfigurationType,i=n.HandlerType,u=MathJax._.input.tex.Configuration,r=u.Configuration,s=(u.ConfigurationHandler,u.ParserConfiguration,MathJax._.input.tex.TokenMap),l=(s.parseResult,s.AbstractTokenMap,s.RegExpMap,s.AbstractParseMap,s.CharacterMap),g=(s.DelimiterMap,s.MacroMap,s.CommandMap,s.EnvironmentMap,MathJax._.input.tex.TexConstants.TexConstant);new l("upgreek",(function(a,e){const p=e.attributes||{};p.mathvariant=g.Variant.NORMAL;const t=a.create("token","mi",p,e.char);a.Push(t)}),{upalpha:"\u03b1",upbeta:"\u03b2",upgamma:"\u03b3",updelta:"\u03b4",upepsilon:"\u03f5",upzeta:"\u03b6",upeta:"\u03b7",uptheta:"\u03b8",upiota:"\u03b9",upkappa:"\u03ba",uplambda:"\u03bb",upmu:"\u03bc",upnu:"\u03bd",upxi:"\u03be",upomicron:"\u03bf",uppi:"\u03c0",uprho:"\u03c1",upsigma:"\u03c3",uptau:"\u03c4",upupsilon:"\u03c5",upphi:"\u03d5",upchi:"\u03c7",uppsi:"\u03c8",upomega:"\u03c9",upvarepsilon:"\u03b5",upvartheta:"\u03d1",upvarpi:"\u03d6",upvarrho:"\u03f1",upvarsigma:"\u03c2",upvarphi:"\u03c6",Upgamma:"\u0393",Updelta:"\u0394",Uptheta:"\u0398",Uplambda:"\u039b",Upxi:"\u039e",Uppi:"\u03a0",Upsigma:"\u03a3",Upupsilon:"\u03a5",Upphi:"\u03a6",Uppsi:"\u03a8",Upomega:"\u03a9"});const c=r.create("upgreek",{[o.HANDLER]:{[i.MACRO]:["upgreek"]}});MathJax.loader&&MathJax.loader.checkVersion("[tex]/upgreek","4.0.0","tex-extension"),t({_:{input:{tex:{upgreek:{UpgreekConfiguration:e}}}}})})();