(()=>{"use strict";var o={d:(e,t)=>{for(var a in t)o.o(t,a)&&!o.o(e,a)&&Object.defineProperty(e,a,{enumerable:!0,get:t[a]})},o:(o,e)=>Object.prototype.hasOwnProperty.call(o,e),r:o=>{"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(o,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(o,"__esModule",{value:!0})}},e={};o.r(e),o.d(e,{ColorConfiguration:()=>u});const t=("undefined"!=typeof window?window:global).MathJax._.components.global,a=(t.GLOBAL,t.isObject,t.combineConfig,t.combineDefaults,t.combineWithMathJax),n=(t.MathJax,MathJax._.input.tex.HandlerTypes),r=n.ConfigurationType,i=n.HandlerType,c=MathJax._.input.tex.TokenMap,l=(c.parseResult,c.AbstractTokenMap,c.RegExpMap,c.AbstractParseMap,c.CharacterMap,c.DelimiterMap,c.MacroMap,c.CommandMap),s=(c.EnvironmentMap,MathJax._.input.tex.Configuration),p=s.Configuration;s.ConfigurationHandler,s.ParserConfiguration;new l("colorv2",{color:{Color(o,e){const t=o.GetArgument(e),a=o.stack.env.color;o.stack.env.color=t;const n=o.ParseArg(e);a?o.stack.env.color=a:delete o.stack.env.color;const r=o.create("node","mstyle",[n],{mathcolor:t});o.Push(r)}}.Color});const u=p.create("colorv2",{[r.HANDLER]:{[i.MACRO]:["colorv2"]}});MathJax.loader&&MathJax.loader.checkVersion("[tex]/colorv2","4.0.0","tex-extension"),a({_:{input:{tex:{colorv2:{ColorV2Configuration:e}}}}})})();