(()=>{"use strict";var t={d:(e,a)=>{for(var o in a)t.o(a,o)&&!t.o(e,o)&&Object.defineProperty(e,o,{enumerable:!0,get:a[o]})},o:(t,e)=>Object.prototype.hasOwnProperty.call(t,e),r:t=>{"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(t,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(t,"__esModule",{value:!0})}},e={};t.r(e),t.d(e,{BbmConfiguration:()=>x,BbmMethods:()=>c});const a=("undefined"!=typeof window?window:global).MathJax._.components.global,o=(a.GLOBAL,a.isObject,a.combineConfig,a.combineDefaults),n=a.combineWithMathJax,b=(a.MathJax,MathJax._.input.tex.HandlerTypes),i=b.ConfigurationType,r=b.HandlerType,s=MathJax._.input.tex.Configuration,m=s.Configuration,d=(s.ConfigurationHandler,s.ParserConfiguration,MathJax._.input.tex.TokenMap),l=(d.parseResult,d.AbstractTokenMap,d.RegExpMap,d.AbstractParseMap,d.CharacterMap,d.DelimiterMap,d.MacroMap,d.CommandMap),h=(d.EnvironmentMap,MathJax._.input.tex.base.BaseMethods),p=(h.splitAlignArray,h.default),c={ChooseFont(t,e,a,o){p.MathFont(t,e,t.options.bbm.bold?o:a)},ChangeBold(t,e){const a=t.GetArgument(e);t.options.bbm.bold="bold"===a},MathFont:p.MathFont};new l("bbm",{mathversion:c.ChangeBold,mathbbm:[c.ChooseFont,"-bbm-normal","-bbm-bold"],mathbbmss:[c.ChooseFont,"-bbm-sans-serif","-bbm-sans-serif-bold"],mathbbmtt:[c.MathFont,"-bbm-monospace"]});const x=m.create("bbm",{[i.HANDLER]:{[r.MACRO]:["bbm"]},[i.OPTIONS]:{bbm:{bold:!1}}});MathJax.loader&&MathJax.loader.checkVersion("[tex]/bbm","4.0.0","tex-extension"),n({_:{input:{tex:{bbm:{BbmConfiguration:e}}}}});const M=MathJax._.util.context,u=M.hasWindow;M.context;!function(t,e,a=`@mathjax/${e}`){if(MathJax.loader){const n=u?`https://cdn.jsdelivr.net/npm/${a}`:a,b=e.replace(/-font-extension$/,"-extension"),i=MathJax.config?.startup?.output||"chtml";o(MathJax.config.loader,"paths",{[b]:n}),o(MathJax.config.loader,"dependencies",{[`[${b}]/${i}`]:[`output/${i}`]}),MathJax.loader.addPackageData(t,{extraLoads:[`[${b}]/${i}`],rendererExtensions:[b]})}}("[tex]/bbm","mathjax-bbm-font-extension")})();