(()=>{"use strict";var e={d:(o,r)=>{for(var t in r)e.o(r,t)&&!e.o(o,t)&&Object.defineProperty(o,t,{enumerable:!0,get:r[t]})},o:(e,o)=>Object.prototype.hasOwnProperty.call(e,o),r:e=>{"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(e,"__esModule",{value:!0})}},o={};e.r(o),e.d(o,{NoErrorsConfiguration:()=>c});const r=("undefined"!=typeof window?window:global).MathJax._.components.global,t=(r.GLOBAL,r.isObject,r.combineConfig,r.combineDefaults,r.combineWithMathJax),n=(r.MathJax,MathJax._.input.tex.HandlerTypes),a=n.ConfigurationType,i=(n.HandlerType,MathJax._.input.tex.Configuration),l=i.Configuration;i.ConfigurationHandler,i.ParserConfiguration;const c=l.create("noerrors",{[a.NODES]:{error:function(e,o,r,t){const n=e.create("token","mtext",{},t.replace(/\n/g," "));return e.create("node","merror",[n],{"data-mjx-error":o,title:o})}}});MathJax.loader&&MathJax.loader.checkVersion("[tex]/noerrors","4.0.0","tex-extension"),t({_:{input:{tex:{noerrors:{NoErrorsConfiguration:o}}}}})})();