(()=>{"use strict";var a={d:(e,p)=>{for(var t in p)a.o(p,t)&&!a.o(e,t)&&Object.defineProperty(e,t,{enumerable:!0,get:p[t]})},o:(a,e)=>Object.prototype.hasOwnProperty.call(a,e),r:a=>{"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(a,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(a,"__esModule",{value:!0})}},e={};a.r(e),a.d(e,{UpgreekConfiguration:()=>c});const p=("undefined"!=typeof window?window:global).MathJax._.components.global,t=(p.GLOBAL,p.isObject,p.combineConfig,p.combineDefaults,p.combineWithMathJax),n=(p.MathJax,MathJax._.input.tex.HandlerTypes),o=n.ConfigurationType,i=n.HandlerType,u=MathJax._.input.tex.Configuration,r=u.Configuration,s=(u.ConfigurationHandler,u.ParserConfiguration,MathJax._.input.tex.TokenMap),l=(s.parseResult,s.AbstractTokenMap,s.RegExpMap,s.AbstractParseMap,s.CharacterMap),g=(s.DelimiterMap,s.MacroMap,s.CommandMap,s.EnvironmentMap,MathJax._.input.tex.TexConstants.TexConstant);new l("upgreek",(function(a,e){const p=e.attributes||{};p.mathvariant=g.Variant.NORMAL;const t=a.create("token","mi",p,e.char);a.Push(t)}),{upalpha:"α",upbeta:"β",upgamma:"γ",updelta:"δ",upepsilon:"ϵ",upzeta:"ζ",upeta:"η",uptheta:"θ",upiota:"ι",upkappa:"κ",uplambda:"λ",upmu:"μ",upnu:"ν",upxi:"ξ",upomicron:"ο",uppi:"π",uprho:"ρ",upsigma:"σ",uptau:"τ",upupsilon:"υ",upphi:"ϕ",upchi:"χ",uppsi:"ψ",upomega:"ω",upvarepsilon:"ε",upvartheta:"ϑ",upvarpi:"ϖ",upvarrho:"ϱ",upvarsigma:"ς",upvarphi:"φ",Upgamma:"Γ",Updelta:"Δ",Uptheta:"Θ",Uplambda:"Λ",Upxi:"Ξ",Uppi:"Π",Upsigma:"Σ",Upupsilon:"Υ",Upphi:"Φ",Uppsi:"Ψ",Upomega:"Ω"});const c=r.create("upgreek",{[o.HANDLER]:{[i.MACRO]:["upgreek"]}});MathJax.loader&&MathJax.loader.checkVersion("[tex]/upgreek","4.0.0","tex-extension"),t({_:{input:{tex:{upgreek:{UpgreekConfiguration:e}}}}})})();