(()=>{"use strict";var t={d:(e,a)=>{for(var r in a)t.o(a,r)&&!t.o(e,r)&&Object.defineProperty(e,r,{enumerable:!0,get:a[r]})},o:(t,e)=>Object.prototype.hasOwnProperty.call(t,e),r:t=>{"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(t,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(t,"__esModule",{value:!0})}},e={};t.r(e),t.d(e,{TextcompConfiguration:()=>h});const a=("undefined"!=typeof window?window:global).MathJax._.components.global,r=(a.GLOBAL,a.isObject,a.combineConfig,a.combineDefaults,a.combineWithMathJax),x=(a.MathJax,MathJax._.input.tex.HandlerTypes),o=x.ConfigurationType,n=x.HandlerType,i=MathJax._.input.tex.Configuration,s=i.Configuration,l=(i.ConfigurationHandler,i.ParserConfiguration,MathJax._.input.tex.TokenMap),c=(l.parseResult,l.AbstractTokenMap,l.RegExpMap,l.AbstractParseMap,l.CharacterMap,l.DelimiterMap,l.MacroMap,l.CommandMap),d=(l.EnvironmentMap,MathJax._.input.tex.TexConstants.TexConstant),p=MathJax._.input.tex.textmacros.TextMacrosMethods.TextMacrosMethods,u=MathJax._.input.tex.ParseUtil,m=(u.KeyValueDef,u.KeyValueTypes,u.ParseUtil),b=MathJax._.input.tex.textmacros.TextParser.TextParser;function g(t,e,a,r){if(t instanceof b){if(!r)return void p.Insert(t,e,a);t.saveText()}t.Push(m.internalText(t,a,r?{mathvariant:r}:{}))}new c("textcomp-macros",{textasciicircum:[g,"^"],textasciitilde:[g,"~"],textasteriskcentered:[g,"*"],textbackslash:[g,"\\"],textbar:[g,"|"],textbraceleft:[g,"{"],textbraceright:[g,"}"],textbullet:[g,"\u2022"],textdagger:[g,"\u2020"],textdaggerdbl:[g,"\u2021"],textellipsis:[g,"\u2026"],textemdash:[g,"\u2014"],textendash:[g,"\u2013"],textexclamdown:[g,"\xa1"],textgreater:[g,">"],textless:[g,"<"],textordfeminine:[g,"\xaa"],textordmasculine:[g,"\xba"],textparagraph:[g,"\xb6"],textperiodcentered:[g,"\xb7"],textquestiondown:[g,"\xbf"],textquotedblleft:[g,"\u201c"],textquotedblright:[g,"\u201d"],textquoteleft:[g,"\u2018"],textquoteright:[g,"\u2019"],textsection:[g,"\xa7"],textunderscore:[g,"_"],textvisiblespace:[g,"\u2423"],textacutedbl:[g,"\u02dd"],textasciiacute:[g,"\xb4"],textasciibreve:[g,"\u02d8"],textasciicaron:[g,"\u02c7"],textasciidieresis:[g,"\xa8"],textasciimacron:[g,"\xaf"],textgravedbl:[g,"\u02f5"],texttildelow:[g,"\u02f7"],textbaht:[g,"\u0e3f"],textcent:[g,"\xa2"],textcolonmonetary:[g,"\u20a1"],textcurrency:[g,"\xa4"],textdollar:[g,"$"],textdong:[g,"\u20ab"],texteuro:[g,"\u20ac"],textflorin:[g,"\u0192"],textguarani:[g,"\u20b2"],textlira:[g,"\u20a4"],textnaira:[g,"\u20a6"],textpeso:[g,"\u20b1"],textsterling:[g,"\xa3"],textwon:[g,"\u20a9"],textyen:[g,"\xa5"],textcircledP:[g,"\u2117"],textcompwordmark:[g,"\u200c"],textcopyleft:[g,"\u{1f12f}"],textcopyright:[g,"\xa9"],textregistered:[g,"\xae"],textservicemark:[g,"\u2120"],texttrademark:[g,"\u2122"],textbardbl:[g,"\u2016"],textbigcircle:[g,"\u25ef"],textblank:[g,"\u2422"],textbrokenbar:[g,"\xa6"],textdiscount:[g,"\u2052"],textestimated:[g,"\u212e"],textinterrobang:[g,"\u203d"],textinterrobangdown:[g,"\u2e18"],textmusicalnote:[g,"\u266a"],textnumero:[g,"\u2116"],textopenbullet:[g,"\u25e6"],textpertenthousand:[g,"\u2031"],textperthousand:[g,"\u2030"],textrecipe:[g,"\u211e"],textreferencemark:[g,"\u203b"],textlangle:[g,"\u2329"],textrangle:[g,"\u232a"],textlbrackdbl:[g,"\u27e6"],textrbrackdbl:[g,"\u27e7"],textlquill:[g,"\u2045"],textrquill:[g,"\u2046"],textcelsius:[g,"\u2103"],textdegree:[g,"\xb0"],textdiv:[g,"\xf7"],textdownarrow:[g,"\u2193"],textfractionsolidus:[g,"\u2044"],textleftarrow:[g,"\u2190"],textlnot:[g,"\xac"],textmho:[g,"\u2127"],textminus:[g,"\u2212"],textmu:[g,"\xb5"],textohm:[g,"\u2126"],textonehalf:[g,"\xbd"],textonequarter:[g,"\xbc"],textonesuperior:[g,"\xb9"],textpm:[g,"\xb1"],textrightarrow:[g,"\u2192"],textsurd:[g,"\u221a"],textthreequarters:[g,"\xbe"],textthreesuperior:[g,"\xb3"],texttimes:[g,"\xd7"],texttwosuperior:[g,"\xb2"],textuparrow:[g,"\u2191"],textborn:[g,"*"],textdied:[g,"\u2020"],textdivorced:[g,"\u26ae"],textmarried:[g,"\u26ad"],textcentoldstyle:[g,"\xa2",d.Variant.OLDSTYLE],textdollaroldstyle:[g,"$",d.Variant.OLDSTYLE],textzerooldstyle:[g,"0",d.Variant.OLDSTYLE],textoneoldstyle:[g,"1",d.Variant.OLDSTYLE],texttwooldstyle:[g,"2",d.Variant.OLDSTYLE],textthreeoldstyle:[g,"3",d.Variant.OLDSTYLE],textfouroldstyle:[g,"4",d.Variant.OLDSTYLE],textfiveoldstyle:[g,"5",d.Variant.OLDSTYLE],textsixoldstyle:[g,"6",d.Variant.OLDSTYLE],textsevenoldstyle:[g,"7",d.Variant.OLDSTYLE],texteightoldstyle:[g,"8",d.Variant.OLDSTYLE],textnineoldstyle:[g,"9",d.Variant.OLDSTYLE]}),s.create("text-textcomp",{[o.PARSER]:"text",[o.HANDLER]:{[n.MACRO]:["textcomp-macros"]}});const h=s.create("textcomp",{[o.HANDLER]:{macro:["textcomp-macros"]},config(t,e){const a=e.parseOptions.packageData.get("textmacros");a&&(a.parseOptions.options.textmacros.packages.push("text-textcomp"),a.textConf.add("text-textcomp",e,{}))}});MathJax.loader&&MathJax.loader.checkVersion("[tex]/textcomp","4.0.0","tex-extension"),r({_:{input:{tex:{textcomp:{TextcompConfiguration:e}}}}})})();