(()=>{"use strict";var t={d:(e,a)=>{for(var n in a)t.o(a,n)&&!t.o(e,n)&&Object.defineProperty(e,n,{enumerable:!0,get:a[n]})},o:(t,e)=>Object.prototype.hasOwnProperty.call(t,e),r:t=>{"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(t,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(t,"__esModule",{value:!0})}},e={};t.r(e),t.d(e,{DsfontConfiguration:()=>u});const a=("undefined"!=typeof window?window:global).MathJax._.components.global,n=(a.GLOBAL,a.isObject,a.combineConfig,a.combineDefaults),o=a.combineWithMathJax,i=(a.MathJax,MathJax._.input.tex.HandlerTypes),r=i.ConfigurationType,s=i.HandlerType,d=MathJax._.input.tex.Configuration,p=d.Configuration,f=(d.ConfigurationHandler,d.ParserConfiguration,MathJax._.input.tex.TokenMap),c=(f.parseResult,f.AbstractTokenMap,f.RegExpMap,f.AbstractParseMap,f.CharacterMap,f.DelimiterMap,f.MacroMap,f.CommandMap),x=(f.EnvironmentMap,MathJax._.input.tex.base.BaseMethods),l=(x.splitAlignArray,x.default);new c("dsfont",{mathds:function(t,e){l.MathFont(t,e,t.options.dsfont.sans?"-ds-ss":"-ds-rm")}});const u=p.create("dsfont",{[r.HANDLER]:{[s.MACRO]:["dsfont"]},[r.OPTIONS]:{dsfont:{sans:!1}}});MathJax.loader&&MathJax.loader.checkVersion("[tex]/dsfont","4.0.0","tex-extension"),o({_:{input:{tex:{dsfont:{DsfontConfiguration:e}}}}});const M=MathJax._.util.context,h=M.hasWindow;M.context;!function(t,e,a=`@mathjax/${e}`){if(MathJax.loader){const o=h?`https://cdn.jsdelivr.net/npm/${a}`:a,i=e.replace(/-font-extension$/,"-extension"),r=MathJax.config?.startup?.output||"chtml";n(MathJax.config.loader,"paths",{[i]:o}),n(MathJax.config.loader,"dependencies",{[`[${i}]/${r}`]:[`output/${r}`]}),MathJax.loader.addPackageData(t,{extraLoads:[`[${i}]/${r}`],rendererExtensions:[i]})}}("[tex]/dsfont","mathjax-dsfont-font-extension")})();