(()=>{"use strict";var e={d:(t,a)=>{for(var n in a)e.o(a,n)&&!e.o(t,n)&&Object.defineProperty(t,n,{enumerable:!0,get:a[n]})},o:(e,t)=>Object.prototype.hasOwnProperty.call(e,t),r:e=>{"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(e,"__esModule",{value:!0})}},t={};e.r(t),e.d(t,{CancelConfiguration:()=>A,CancelMethods:()=>O});const a=("undefined"!=typeof window?window:global).MathJax._.components.global,n=(a.GLOBAL,a.isObject,a.combineConfig,a.combineDefaults,a.combineWithMathJax),o=(a.MathJax,MathJax._.input.tex.HandlerTypes),c=o.ConfigurationType,i=o.HandlerType,r=MathJax._.input.tex.Configuration,l=r.Configuration,s=(r.ConfigurationHandler,r.ParserConfiguration,MathJax._.input.tex.TexConstants.TexConstant),p=MathJax._.input.tex.TokenMap,u=(p.parseResult,p.AbstractTokenMap,p.RegExpMap,p.AbstractParseMap,p.CharacterMap,p.DelimiterMap,p.MacroMap,p.CommandMap),d=(p.EnvironmentMap,MathJax._.input.tex.ParseUtil),M=(d.KeyValueDef,d.KeyValueTypes,d.ParseUtil),x=MathJax._.input.tex.enclose.EncloseConfiguration,C=x.ENCLOSE_OPTIONS,O=(x.EncloseMethods,x.EncloseConfiguration,{Cancel(e,t,a){const n=e.GetBrackets(t,""),o=e.ParseArg(t),c=M.keyvalOptions(n,C);c.notation=a,e.Push(e.create("node","menclose",[o],c))},CancelTo(e,t){const a=e.GetBrackets(t,"");let n=e.ParseArg(t);const o=e.ParseArg(t),c=M.keyvalOptions(a,C);c.notation=[s.Notation.UPDIAGONALSTRIKE,s.Notation.UPDIAGONALARROW,s.Notation.NORTHEASTARROW].join(" "),n=e.create("node","mpadded",[n],{depth:"-.1em",height:"+.1em",voffset:".1em"}),e.Push(e.create("node","msup",[e.create("node","menclose",[o],c),n]))}});new u("cancel",{cancel:[O.Cancel,s.Notation.UPDIAGONALSTRIKE],bcancel:[O.Cancel,s.Notation.DOWNDIAGONALSTRIKE],xcancel:[O.Cancel,s.Notation.UPDIAGONALSTRIKE+" "+s.Notation.DOWNDIAGONALSTRIKE],cancelto:O.CancelTo});const A=l.create("cancel",{[c.HANDLER]:{[i.MACRO]:["cancel"]}});MathJax.loader&&MathJax.loader.checkVersion("[tex]/cancel","4.0.0","tex-extension"),n({_:{input:{tex:{cancel:{CancelConfiguration:t}}}}})})();